@@ -8,6 +8,11 @@ import time
 import uuid
 
 
+@unique
+class ResourceTypeExceptionValueSet(Enum):
+    RESOURCE_TYPE = "ResourceType"
+
+
 @unique
 class ServiceNamespaceValueSet(Enum):
     APPSTREAM = "appstream"
@@ -74,7 +79,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
     def describe_scalable_targets(
         self, namespace, r_ids=None, dimension=None,
     ):
-        """ Describe scalable targets. """
+        """Describe scalable targets."""
         if r_ids is None:
             r_ids = []
         targets = self._flatten_scalable_targets(namespace)
@@ -85,7 +90,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
         return targets
 
     def _flatten_scalable_targets(self, namespace):
-        """ Flatten scalable targets for a given service namespace down to a list. """
+        """Flatten scalable targets for a given service namespace down to a list."""
         targets = []
         for dimension in self.targets.keys():
             for resource_id in self.targets[dimension].keys():
@@ -94,7 +99,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
         return targets
 
     def register_scalable_target(self, namespace, r_id, dimension, **kwargs):
-        """ Registers or updates a scalable target. """
+        """Registers or updates a scalable target."""
         _ = _target_params_are_valid(namespace, r_id, dimension)
         if namespace == ServiceNamespaceValueSet.ECS.value:
             _ = self._ecs_service_exists_for_target(r_id)
@@ -127,7 +132,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
         return target
 
     def deregister_scalable_target(self, namespace, r_id, dimension):
-        """ Registers or updates a scalable target. """
+        """Registers or updates a scalable target."""
         if self._scalable_target_exists(r_id, dimension):
             del self.targets[dimension][r_id]
         else:
@@ -222,7 +227,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
 
 
 def _target_params_are_valid(namespace, r_id, dimension):
-    """ Check whether namespace, resource_id and dimension are valid and consistent with each other. """
+    """Check whether namespace, resource_id and dimension are valid and consistent with each other."""
     is_valid = True
     valid_namespaces = [n.value for n in ServiceNamespaceValueSet]
     if namespace not in valid_namespaces:
@@ -230,8 +235,12 @@ def _target_params_are_valid(namespace, r_id, dimension):
     if dimension is not None:
         try:
             valid_dimensions = [d.value for d in ScalableDimensionValueSet]
+            resource_type_exceptions = [r.value for r in ResourceTypeExceptionValueSet]
             d_namespace, d_resource_type, scaling_property = dimension.split(":")
-            resource_type = _get_resource_type_from_resource_id(r_id)
+            if d_resource_type not in resource_type_exceptions:
+                resource_type = _get_resource_type_from_resource_id(r_id)
+            else:
+                resource_type = d_resource_type
             if (
                 dimension not in valid_dimensions
                 or d_namespace != namespace
@@ -311,7 +320,7 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
         self.step_scaling_policy_configuration = None
         self.target_tracking_scaling_policy_configuration = None
 
-        if "policy_type" == "StepScaling":
+        if policy_type == "StepScaling":
             self.step_scaling_policy_configuration = policy_body
             self.target_tracking_scaling_policy_configuration = None
         elif policy_type == "TargetTrackingScaling":
