@@ -168,7 +168,7 @@ def are_dimensions_same(metric_dimensions, dimensions):
 
 
 class MetricDatum(BaseModel):
-    def __init__(self, namespace, name, value, dimensions, timestamp):
+    def __init__(self, namespace, name, value, dimensions, timestamp, unit=None):
         self.namespace = namespace
         self.name = name
         self.value = value
@@ -176,6 +176,7 @@ class MetricDatum(BaseModel):
         self.dimensions = [
             Dimension(dimension["Name"], dimension["Value"]) for dimension in dimensions
         ]
+        self.unit = unit
 
     def filter(self, namespace, name, dimensions, already_present_metrics):
         if namespace and namespace != self.namespace:
@@ -385,6 +386,7 @@ class CloudWatchBackend(BaseBackend):
                     float(metric_member.get("Value", 0)),
                     metric_member.get("Dimensions.member", _EMPTY_LIST),
                     timestamp,
+                    metric_member.get("Unit"),
                 )
             )
 
@@ -449,7 +451,7 @@ class CloudWatchBackend(BaseBackend):
         return results
 
     def get_metric_statistics(
-        self, namespace, metric_name, start_time, end_time, period, stats
+        self, namespace, metric_name, start_time, end_time, period, stats, unit=None
     ):
         period_delta = timedelta(seconds=period)
         filtered_data = [
@@ -460,6 +462,9 @@ class CloudWatchBackend(BaseBackend):
             and start_time <= md.timestamp <= end_time
         ]
 
+        if unit:
+            filtered_data = [md for md in filtered_data if md.unit == unit]
+
         # earliest to oldest
         filtered_data = sorted(filtered_data, key=lambda x: x.timestamp)
         if not filtered_data:
