@@ -5,11 +5,9 @@ from moto.core.exceptions import RESTError, JsonRESTError
 class ServiceNotFoundException(RESTError):
     code = 400
 
-    def __init__(self, service_name):
+    def __init__(self):
         super(ServiceNotFoundException, self).__init__(
-            error_type="ServiceNotFoundException",
-            message="The service {0} does not exist".format(service_name),
-            template="error_json",
+            error_type="ServiceNotFoundException", message="Service not found."
         )
 
 
@@ -23,6 +21,15 @@ class TaskDefinitionNotFoundException(JsonRESTError):
         )
 
 
+class RevisionNotFoundException(JsonRESTError):
+    code = 400
+
+    def __init__(self):
+        super(RevisionNotFoundException, self).__init__(
+            error_type="ClientException", message="Revision is missing.",
+        )
+
+
 class TaskSetNotFoundException(JsonRESTError):
     code = 400
 
@@ -38,5 +45,14 @@ class ClusterNotFoundException(JsonRESTError):
 
     def __init__(self):
         super(ClusterNotFoundException, self).__init__(
-            error_type="ClientException", message="Cluster not found",
+            error_type="ClusterNotFoundException", message="Cluster not found.",
+        )
+
+
+class InvalidParameterException(JsonRESTError):
+    code = 400
+
+    def __init__(self, message):
+        super(InvalidParameterException, self).__init__(
+            error_type="ClientException", message=message,
         )
