@@ -326,7 +326,6 @@ class FakeListenerRule(CloudFormationModel):
         conditions = properties.get("Conditions")
 
         actions = elbv2_backend.convert_and_validate_action_properties(properties)
-        conditions = elbv2_backend.convert_and_validate_condition_properties(properties)
         listener_rule = elbv2_backend.create_rule(
             listener_arn, conditions, priority, actions
         )
@@ -343,7 +342,6 @@ class FakeListenerRule(CloudFormationModel):
         conditions = properties.get("Conditions")
 
         actions = elbv2_backend.convert_and_validate_action_properties(properties)
-        conditions = elbv2_backend.convert_and_validate_condition_properties(properties)
         listener_rule = elbv2_backend.modify_rule(
             original_resource.arn, conditions, actions
         )
@@ -660,15 +658,6 @@ class ELBv2Backend(BaseBackend):
                 raise InvalidActionTypeError(action_type, i + 1)
         return default_actions
 
-    def convert_and_validate_condition_properties(self, properties):
-
-        conditions = []
-        for i, condition in enumerate(properties["Conditions"]):
-            conditions.append(
-                {"field": condition["Field"], "values": condition["Values"],}
-            )
-        return conditions
-
     def create_rule(self, listener_arn, conditions, priority, actions):
         actions = [FakeAction(action) for action in actions]
         listeners = self.describe_listeners(None, [listener_arn])
@@ -677,22 +666,7 @@ class ELBv2Backend(BaseBackend):
         listener = listeners[0]
 
         # validate conditions
-        for condition in conditions:
-            if "field" in condition:
-                field = condition["field"]
-                if field not in ["path-pattern", "host-header"]:
-                    raise InvalidConditionFieldError(field)
-
-                values = condition["values"]
-                if len(values) == 0:
-                    raise InvalidConditionValueError(
-                        "A condition value must be specified"
-                    )
-                if len(values) > 1:
-                    raise InvalidConditionValueError(
-                        "The '%s' field contains too many values; the limit is '1'"
-                        % field
-                    )
+        self._validate_conditions(conditions)
 
         # TODO: check pattern of value for 'host-header'
         # TODO: check pattern of value for 'path-pattern'
@@ -714,6 +688,136 @@ class ELBv2Backend(BaseBackend):
         listener.register(arn, rule)
         return rule
 
+    def _validate_conditions(self, conditions):
+        for condition in conditions:
+            if "Field" in condition:
+                field = condition["Field"]
+                if field not in [
+                    "host-header",
+                    "http-header",
+                    "http-request-method",
+                    "path-pattern",
+                    "query-string",
+                    "source-ip",
+                ]:
+                    raise InvalidConditionFieldError(field)
+                if "Values" in condition and field not in [
+                    "host-header",
+                    "path-pattern",
+                ]:
+                    raise InvalidConditionValueError(
+                        "The 'Values' field is not compatible with '%s'" % field
+                    )
+                else:
+                    method_name = "_validate_" + field.replace("-", "_") + "_condition"
+                    func = getattr(self, method_name)
+                    func(condition)
+
+    def _validate_host_header_condition(self, condition):
+        values = None
+        if "HostHeaderConfig" in condition:
+            values = condition["HostHeaderConfig"]["Values"]
+        elif "Values" in condition:
+            values = condition["Values"]
+            if len(values) > 1:
+                raise InvalidConditionValueError(
+                    "The 'host-header' field contains too many values; the limit is '1'"
+                )
+        if values is None or len(values) == 0:
+            raise InvalidConditionValueError("A condition value must be specified")
+        for value in values:
+            if len(value) > 128:
+                raise InvalidConditionValueError(
+                    "The 'host-header' value is too long; the limit is '128'"
+                )
+
+    def _validate_http_header_condition(self, condition):
+        if "HttpHeaderConfig" in condition:
+            config = condition["HttpHeaderConfig"]
+            name = config.get("HttpHeaderName")
+            if len(name) > 40:
+                raise InvalidConditionValueError(
+                    "The 'HttpHeaderName' value is too long; the limit is '40'"
+                )
+            values = config["Values"]
+            for value in values:
+                if len(value) > 128:
+                    raise InvalidConditionValueError(
+                        "The 'http-header' value is too long; the limit is '128'"
+                    )
+        else:
+            raise InvalidConditionValueError(
+                "A 'HttpHeaderConfig' must be specified with 'http-header'"
+            )
+
+    def _validate_http_request_method_condition(self, condition):
+        if "HttpRequestMethodConfig" in condition:
+            for value in condition["HttpRequestMethodConfig"]["Values"]:
+                if len(value) > 40:
+                    raise InvalidConditionValueError(
+                        "The 'http-request-method' value is too long; the limit is '40'"
+                    )
+                if not re.match("[A-Z_-]+", value):
+                    raise InvalidConditionValueError(
+                        "The 'http-request-method' value is invalid; the allowed characters are A-Z, hyphen and underscore"
+                    )
+        else:
+            raise InvalidConditionValueError(
+                "A 'HttpRequestMethodConfig' must be specified with 'http-request-method'"
+            )
+
+    def _validate_path_pattern_condition(self, condition):
+        values = None
+        if "PathPatternConfig" in condition:
+            values = condition["PathPatternConfig"]["Values"]
+        elif "Values" in condition:
+            values = condition["Values"]
+            if len(values) > 1:
+                raise InvalidConditionValueError(
+                    "The 'path-pattern' field contains too many values; the limit is '1'"
+                )
+        if values is None or len(values) == 0:
+            raise InvalidConditionValueError("A condition value must be specified")
+        for value in values:
+            if len(value) > 128:
+                raise InvalidConditionValueError(
+                    "The 'path-pattern' value is too long; the limit is '128'"
+                )
+
+    def _validate_source_ip_condition(self, condition):
+        if "SourceIpConfig" in condition:
+            values = condition["SourceIpConfig"].get("Values", [])
+            if len(values) == 0:
+                raise InvalidConditionValueError(
+                    "A 'source-ip' value must be specified"
+                )
+        else:
+            raise InvalidConditionValueError(
+                "A 'SourceIpConfig' must be specified with 'source-ip'"
+            )
+
+    def _validate_query_string_condition(self, condition):
+        if "QueryStringConfig" in condition:
+            config = condition["QueryStringConfig"]
+            values = config["Values"]
+            for value in values:
+                if "Value" not in value:
+                    raise InvalidConditionValueError(
+                        "A 'Value' must be specified in 'QueryStringKeyValuePair'"
+                    )
+                if "Key" in value and len(value["Key"]) > 128:
+                    raise InvalidConditionValueError(
+                        "The 'Key' value is too long; the limit is '128'"
+                    )
+                if len(value["Value"]) > 128:
+                    raise InvalidConditionValueError(
+                        "The 'Value' value is too long; the limit is '128'"
+                    )
+        else:
+            raise InvalidConditionValueError(
+                "A 'QueryStringConfig' must be specified with 'query-string'"
+            )
+
     def _validate_actions(self, actions):
         # validate Actions
         target_group_arns = [
@@ -1063,24 +1167,9 @@ Member must satisfy regular expression pattern: {}".format(
             raise RuleNotFoundError()
         rule = rules[0]
 
-        if conditions:
-            for condition in conditions:
-                field = condition["field"]
-                if field not in ["path-pattern", "host-header"]:
-                    raise InvalidConditionFieldError(field)
-
-                values = condition["values"]
-                if len(values) == 0:
-                    raise InvalidConditionValueError(
-                        "A condition value must be specified"
-                    )
-                if len(values) > 1:
-                    raise InvalidConditionValueError(
-                        "The '%s' field contains too many values; the limit is '1'"
-                        % field
-                    )
-                # TODO: check pattern of value for 'host-header'
-                # TODO: check pattern of value for 'path-pattern'
+        self._validate_conditions(conditions)
+        # TODO: check pattern of value for 'host-header'
+        # TODO: check pattern of value for 'path-pattern'
 
         # validate Actions
         self._validate_actions(actions)
