@@ -494,7 +494,7 @@ class IamResponse(BaseResponse):
         max_items = self._get_param("MaxItems")
         users = iam_backend.list_users(path_prefix, marker, max_items)
         template = self.response_template(LIST_USERS_TEMPLATE)
-        return template.render(action="List", users=users)
+        return template.render(action="List", users=users, isTruncated=False)
 
     def update_user(self):
         user_name = self._get_param("UserName")
@@ -1725,6 +1725,7 @@ USER_TEMPLATE = """<{{ action }}UserResponse>
 
 LIST_USERS_TEMPLATE = """<{{ action }}UsersResponse>
    <{{ action }}UsersResult>
+    <IsTruncated>{{ isTruncated }}</IsTruncated>
       <Users>
          {% for user in users %}
          <member>
