@@ -1,4 +1,5 @@
 from __future__ import unicode_literals
+
 from .responses import MediaStoreResponse
 
 url_bases = [
@@ -7,6 +8,4 @@ url_bases = [
 
 response = MediaStoreResponse()
 
-url_paths = {
-    "{0}/$": response.dispatch,
-}
+url_paths = {"{0}/$": response.dispatch, "{0}/(?P<Path>[^/.]+)$": response.dispatch}
