@@ -33,19 +33,22 @@ class StepFunctionResponse(BaseResponse):
 
     @amzn_request_id
     def list_state_machines(self):
-        list_all = self.stepfunction_backend.list_state_machines()
-        list_all = sorted(
-            [
-                {
-                    "creationDate": sm.creation_date,
-                    "name": sm.name,
-                    "stateMachineArn": sm.arn,
-                }
-                for sm in list_all
-            ],
-            key=lambda x: x["name"],
+        max_results = self._get_int_param("maxResults")
+        next_token = self._get_param("nextToken")
+        results, next_token = self.stepfunction_backend.list_state_machines(
+            max_results=max_results, next_token=next_token
         )
-        response = {"stateMachines": list_all}
+        state_machines = [
+            {
+                "creationDate": sm.creation_date,
+                "name": sm.name,
+                "stateMachineArn": sm.arn,
+            }
+            for sm in results
+        ]
+        response = {"stateMachines": state_machines}
+        if next_token:
+            response["nextToken"] = next_token
         return 200, {}, json.dumps(response)
 
     @amzn_request_id
@@ -80,6 +83,22 @@ class StepFunctionResponse(BaseResponse):
         except AWSError as err:
             return err.response()
 
+    @amzn_request_id
+    def update_state_machine(self):
+        arn = self._get_param("stateMachineArn")
+        definition = self._get_param("definition")
+        role_arn = self._get_param("roleArn")
+        try:
+            state_machine = self.stepfunction_backend.update_state_machine(
+                arn=arn, definition=definition, role_arn=role_arn
+            )
+            response = {
+                "updateDate": state_machine.update_date,
+            }
+            return 200, {}, json.dumps(response)
+        except AWSError as err:
+            return err.response()
+
     @amzn_request_id
     def list_tags_for_resource(self):
         arn = self._get_param("resourceArn")
@@ -91,6 +110,26 @@ class StepFunctionResponse(BaseResponse):
         response = {"tags": tags}
         return 200, {}, json.dumps(response)
 
+    @amzn_request_id
+    def tag_resource(self):
+        arn = self._get_param("resourceArn")
+        tags = self._get_param("tags", [])
+        try:
+            self.stepfunction_backend.tag_resource(arn, tags)
+        except AWSError as err:
+            return err.response()
+        return 200, {}, json.dumps({})
+
+    @amzn_request_id
+    def untag_resource(self):
+        arn = self._get_param("resourceArn")
+        tag_keys = self._get_param("tagKeys", [])
+        try:
+            self.stepfunction_backend.untag_resource(arn, tag_keys)
+        except AWSError as err:
+            return err.response()
+        return 200, {}, json.dumps({})
+
     @amzn_request_id
     def start_execution(self):
         arn = self._get_param("stateMachineArn")
@@ -110,9 +149,20 @@ class StepFunctionResponse(BaseResponse):
 
     @amzn_request_id
     def list_executions(self):
+        max_results = self._get_int_param("maxResults")
+        next_token = self._get_param("nextToken")
         arn = self._get_param("stateMachineArn")
-        state_machine = self.stepfunction_backend.describe_state_machine(arn)
-        executions = self.stepfunction_backend.list_executions(arn)
+        status_filter = self._get_param("statusFilter")
+        try:
+            state_machine = self.stepfunction_backend.describe_state_machine(arn)
+            results, next_token = self.stepfunction_backend.list_executions(
+                arn,
+                status_filter=status_filter,
+                max_results=max_results,
+                next_token=next_token,
+            )
+        except AWSError as err:
+            return err.response()
         executions = [
             {
                 "executionArn": execution.execution_arn,
@@ -121,9 +171,12 @@ class StepFunctionResponse(BaseResponse):
                 "stateMachineArn": state_machine.arn,
                 "status": execution.status,
             }
-            for execution in executions
+            for execution in results
         ]
-        return 200, {}, json.dumps({"executions": executions})
+        response = {"executions": executions}
+        if next_token:
+            response["nextToken"] = next_token
+        return 200, {}, json.dumps(response)
 
     @amzn_request_id
     def describe_execution(self):
@@ -155,6 +208,21 @@ class StepFunctionResponse(BaseResponse):
     @amzn_request_id
     def stop_execution(self):
         arn = self._get_param("executionArn")
-        execution = self.stepfunction_backend.stop_execution(arn)
-        response = {"stopDate": execution.stop_date}
-        return 200, {}, json.dumps(response)
+        try:
+            execution = self.stepfunction_backend.stop_execution(arn)
+            response = {"stopDate": execution.stop_date}
+            return 200, {}, json.dumps(response)
+        except AWSError as err:
+            return err.response()
+
+    @amzn_request_id
+    def get_execution_history(self):
+        execution_arn = self._get_param("executionArn")
+        try:
+            execution_history = self.stepfunction_backend.get_execution_history(
+                execution_arn
+            )
+            response = {"events": execution_history}
+            return 200, {}, json.dumps(response)
+        except AWSError as err:
+            return err.response()
