@@ -112,7 +112,12 @@ class SWFBackend(BaseBackend):
     ):
         if self._get_domain(name, ignore_empty=True):
             raise SWFDomainAlreadyExistsFault(name)
-        domain = Domain(name, workflow_execution_retention_period_in_days, description)
+        domain = Domain(
+            name,
+            workflow_execution_retention_period_in_days,
+            self.region_name,
+            description,
+        )
         self.domains.append(domain)
 
     def deprecate_domain(self, name):
