@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from collections import defaultdict
 
-from moto.core import BaseModel
+from moto.core import ACCOUNT_ID, BaseModel
 from ..exceptions import (
     SWFUnknownResourceFault,
     SWFWorkflowExecutionAlreadyStartedFault,
@@ -9,9 +9,10 @@ from ..exceptions import (
 
 
 class Domain(BaseModel):
-    def __init__(self, name, retention, description=None):
+    def __init__(self, name, retention, region_name, description=None):
         self.name = name
         self.retention = retention
+        self.region_name = region_name
         self.description = description
         self.status = "REGISTERED"
         self.types = {"activity": defaultdict(dict), "workflow": defaultdict(dict)}
@@ -31,6 +32,9 @@ class Domain(BaseModel):
         hsh = {"name": self.name, "status": self.status}
         if self.description:
             hsh["description"] = self.description
+        hsh["arn"] = "arn:aws:swf:{0}:{1}:/domain/{2}".format(
+            self.region_name, ACCOUNT_ID, self.name
+        )
         return hsh
 
     def to_full_dict(self):
